@@ -4,244 +4,253 @@
 <context>
     <name>Data::SyncthingConnection</name>
     <message>
-        <location filename="../syncthingconnection.cpp" line="160"/>
+        <location filename="../syncthingconnection.cpp" line="154"/>
         <source>disconnected</source>
         <translation>Verbindung getrennt</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="162"/>
+        <location filename="../syncthingconnection.cpp" line="156"/>
         <source>reconnecting</source>
         <translation>Verbindung wird hergestellt</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="164"/>
+        <location filename="../syncthingconnection.cpp" line="158"/>
         <source>connected</source>
         <translation>verbunden</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="166"/>
+        <location filename="../syncthingconnection.cpp" line="160"/>
         <source>connected, scanning</source>
         <translation>verbunden, scannt</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="168"/>
+        <location filename="../syncthingconnection.cpp" line="162"/>
         <source>connected, paused</source>
         <translation>verbunden, pausiert</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="170"/>
+        <location filename="../syncthingconnection.cpp" line="164"/>
         <source>connected, synchronizing</source>
         <translation>verbunden, am Synchronisieren</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="172"/>
-        <source>connected, out of sync</source>
-        <translation>verbunden, nicht synchronisiert</translation>
+        <location filename="../syncthingconnection.cpp" line="166"/>
+        <source>connected, remote not in sync</source>
+        <translation>verbunden, entferntes Gerät nicht synchronisiert</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="174"/>
+        <location filename="../syncthingconnection.cpp" line="706"/>
+        <source>Unable to parse timestamp &quot;%1&quot; (%2): %3</source>
+        <translation>Fehler beim Parsen des Zeitstempels &quot;%1&quot; (Kontext: &quot;%2&quot;): %3</translation>
+    </message>
+    <message>
+        <source>connected, out of sync</source>
+        <translation type="vanished">verbunden, nicht synchronisiert</translation>
+    </message>
+    <message>
+        <location filename="../syncthingconnection.cpp" line="168"/>
         <source>unknown</source>
         <translation>Verbindungsstatus unbekannt</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="228"/>
-        <location filename="../syncthingconnection.cpp" line="411"/>
+        <location filename="../syncthingconnection.cpp" line="265"/>
+        <location filename="../syncthingconnection.cpp" line="460"/>
         <source>Connection configuration is insufficient.</source>
         <translation>Verbindungskonfiguration is ungenügend</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="373"/>
+        <location filename="../syncthingconnection_requests.cpp" line="429"/>
         <source>Unable to rescan: No directory ID specified.</source>
         <translation>Fehler beim Anfordern eines Scans: keine Verzeichnis-ID angegeben.</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="197"/>
+        <location filename="../syncthingconnection_requests.cpp" line="253"/>
         <source>Unable to pause/resume a devices when not connected</source>
         <translation>Fehler beim Anfordern Verzeichnis zu Pausieren/Fortzusetzen</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="305"/>
+        <location filename="../syncthingconnection_requests.cpp" line="361"/>
         <source>Unable to pause/resume a directories when not connected</source>
         <translation>Fehler beim Anfordern Gerät zu Pausieren/Fortzusetzen</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1284"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1347"/>
         <source>Unable to request QR-Code: </source>
         <translation>Fehler beim Abfragen des QR-Codes: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1317"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1380"/>
         <source>Unable to parse Syncthing log: </source>
         <translation>Fehler beim Auslesen des Syncthing-Logs: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1334"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1397"/>
         <source>Unable to request Syncthing log: </source>
         <translation>Fehler beim Abfragen des Syncthing-Logs: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="708"/>
+        <location filename="../syncthingconnection.cpp" line="774"/>
         <source>Unable to locate certificate used by Syncthing.</source>
         <translation>Das SSL-Zertifikat von Syncthing kann nicht gefunden werden.</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="714"/>
+        <location filename="../syncthingconnection.cpp" line="780"/>
         <source>Unable to load certificate used by Syncthing.</source>
         <translation>Das SSL-Zertifikat von Syncthing kann nicht ausgelesen werden.</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="530"/>
+        <location filename="../syncthingconnection_requests.cpp" line="585"/>
         <source>Unable to parse Syncthing config: </source>
         <translation>Fehler beim Auslesen der Syncthing-Konfiguration: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="552"/>
+        <location filename="../syncthingconnection_requests.cpp" line="607"/>
         <source>Unable to request Syncthing config: </source>
         <translation>Fehler beim Abfragen der Syncthing-Konfiguration: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="669"/>
+        <location filename="../syncthingconnection_requests.cpp" line="728"/>
         <source>Unable to parse Syncthing status: </source>
         <translation>Fehler beim Auslesen des Syncthing-Status: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="687"/>
+        <location filename="../syncthingconnection_requests.cpp" line="747"/>
         <source>Unable to request Syncthing status: </source>
         <translation>Fehler beim Abfragen des Syncthing-Status: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="735"/>
+        <location filename="../syncthingconnection_requests.cpp" line="794"/>
         <source>Unable to parse connections: </source>
         <translation>Fehler beim Auslesen der Verbindungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="810"/>
+        <location filename="../syncthingconnection_requests.cpp" line="869"/>
         <source>Unable to request connections: </source>
         <translation>Fehler beim Abfragen der Verbindungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="912"/>
+        <location filename="../syncthingconnection_requests.cpp" line="966"/>
         <source>Unable to parse directory statistics: </source>
         <translation>Fehler beim Auslesen der Verzeichnisstatistiken: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="965"/>
-        <location filename="../syncthingconnection_requests.cpp" line="1023"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1014"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1071"/>
         <source>Unable to request directory statistics: </source>
         <translation>Fehler beim Abfragen der Verzeichnisstatistiken: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1173"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1241"/>
         <source>Unable to parse device statistics: </source>
         <translation>Fehler beim Auslesen der Gerätestatistiken: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1204"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1268"/>
         <source>Unable to request device statistics: </source>
         <translation>Fehler beim Abfragen der Gerätestatistiken: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="849"/>
+        <location filename="../syncthingconnection_requests.cpp" line="907"/>
         <source>Unable to parse errors: </source>
         <translation>Fehler beim Auslesen der Syncthing-Fehlermeldungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="880"/>
+        <location filename="../syncthingconnection_requests.cpp" line="935"/>
         <source>Unable to request errors: </source>
         <translation>Fehler beim Abfragen der Syncthing-Fehlermeldungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="494"/>
+        <location filename="../syncthingconnection_requests.cpp" line="550"/>
         <source>Unable to request clearing errors: </source>
         <translation>Fehler beim Löschen der Fehlermeldungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1532"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1608"/>
         <source>Unable to parse Syncthing events: </source>
         <translation>Fehler beim Auslesen der Syncthing-Ereignisse: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1557"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1631"/>
         <source>Unable to request Syncthing events: </source>
         <translation>Fehler beim Abfragen der Syncthing-Ereignisse: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1375"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1437"/>
         <source>Unable to post config: </source>
         <translation>Fehler beim Senden der neuen Konfiguration: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="403"/>
+        <location filename="../syncthingconnection_requests.cpp" line="459"/>
         <source>Unable to request rescan: </source>
         <translation>Fehler beim Anfordern eines Verzeichnis-Rescans: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="238"/>
+        <location filename="../syncthingconnection_requests.cpp" line="294"/>
         <source>Unable to request device pause/resume: </source>
         <translation>Fehler beim Anfordern Gerät zu Pausieren/Fortzusetzen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="342"/>
+        <location filename="../syncthingconnection_requests.cpp" line="398"/>
         <source>Unable to request directory pause/resume: </source>
         <translation>Fehler beim Anfordern Verzeichnis zu Pausieren/Fortzusetzen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="434"/>
+        <location filename="../syncthingconnection_requests.cpp" line="490"/>
         <source>Unable to request restart: </source>
         <translation>Fehler beim Anfordern eines Neustarts: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="463"/>
+        <location filename="../syncthingconnection_requests.cpp" line="519"/>
         <source>Unable to request shutdown: </source>
         <translation>Fehler beim Anfordern Syncthing zu beenden: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1008"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1056"/>
         <source>Unable to parse status for directory %1: </source>
         <translation>Fehler beim Auslesen des Status von Verzeichnis %1: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1071"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1118"/>
         <source>Unable to parse pull errors for directory %1: </source>
         <translation>Fehler beim Auslesen der Fehler von Verzeichnis %1: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1081"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1128"/>
         <source>Unable to request pull errors for directory %1: </source>
         <translation>Fehler beim Anfordern der Fehler von Verzeichnis %1: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1127"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1194"/>
         <source>Unable to parse completion for device/directory %1/%2: </source>
         <translation>Fehler beim Auslesen des Fortschrittes von Verzeichnis %1/%2: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1141"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1209"/>
         <source>Unable to request completion for device/directory %1/%2: </source>
         <translation>Fehler beim Anfordern des Fortschrittes von Verzeichnis %1/%2: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1233"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1296"/>
         <source>Unable to parse version: </source>
         <translation>Fehler beim Auslesen der Syncthing-Version: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1249"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1312"/>
         <source>Unable to request version: </source>
         <translation>Fehler beim Anfordern der Syncthing-Version: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="2067"/>
+        <location filename="../syncthingconnection_requests.cpp" line="2191"/>
         <source>Unable to parse disk events: </source>
         <translation>Fehler beim Auslesen der letzten Änderungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="2082"/>
+        <location filename="../syncthingconnection_requests.cpp" line="2212"/>
         <source>Unable to request disk events: </source>
         <translation>Fehler beim Anfordern der letzten Änderungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="861"/>
+        <location filename="../syncthingconnection.cpp" line="947"/>
         <source>at offset %1</source>
         <translation>bei Zeichen %1</translation>
     </message>
@@ -279,17 +288,21 @@
         <translation>Fehler beim Starten von Syncthing</translation>
     </message>
     <message>
-        <location filename="../syncthingnotifier.cpp" line="107"/>
+        <location filename="../syncthingnotifier.cpp" line="108"/>
         <source>Maybe the configured binary path is wrong or the binary is not marked as executable.</source>
         <translation>Vielleicht ist der konfigurierte Pfad zu Syncthing falsch oder die Datei nicht als ausführbar markiert.</translation>
     </message>
     <message>
-        <location filename="../syncthingnotifier.cpp" line="110"/>
-        <source>Syncthing crashed with exit code %1</source>
-        <translation>Syncthing is mit dem Exit-Code %1 abgestürtzt</translation>
+        <location filename="../syncthingnotifier.cpp" line="111"/>
+        <source>Syncthing crashed</source>
+        <translation>Syncthing ist abgestürtzt</translation>
     </message>
     <message>
-        <location filename="../syncthingnotifier.cpp" line="113"/>
+        <source>Syncthing crashed with exit code %1</source>
+        <translation type="vanished">Syncthing ist mit dem Exit-Code %1 abgestürtzt</translation>
+    </message>
+    <message>
+        <location filename="../syncthingnotifier.cpp" line="114"/>
         <source>Syncthing launcher error occurred</source>
         <translation>Bei der Ausführung von Syncthing ist ein Fehler aufgetreten</translation>
     </message>
@@ -297,45 +310,50 @@
 <context>
     <name>Data::SyncthingService</name>
     <message>
-        <location filename="../syncthingservice.cpp" line="205"/>
+        <location filename="../syncthingservice.cpp" line="378"/>
         <source>start unit</source>
-        <translation></translation>
+        <translation>Starten der Unit</translation>
     </message>
     <message>
-        <location filename="../syncthingservice.cpp" line="207"/>
+        <location filename="../syncthingservice.cpp" line="380"/>
         <source>stop unit</source>
-        <translation></translation>
+        <translation>Stoppen der Unit</translation>
     </message>
     <message>
-        <location filename="../syncthingservice.cpp" line="219"/>
+        <location filename="../syncthingservice.cpp" line="395"/>
         <source>enable unit</source>
-        <translation></translation>
+        <translation>Aktivieren der Unit</translation>
     </message>
     <message>
-        <location filename="../syncthingservice.cpp" line="221"/>
+        <location filename="../syncthingservice.cpp" line="397"/>
         <source>disable unit</source>
-        <translation></translation>
+        <translation>Deaktivieren der Unit</translation>
+    </message>
+    <message>
+        <location filename="../syncthingservice.cpp" line="407"/>
+        <source>reload all unit files</source>
+        <translation>Aktualisieren aller Unit-Dateien</translation>
     </message>
 </context>
 <context>
     <name>Data::Utils</name>
     <message>
-        <location filename="../utils.cpp" line="28"/>
+        <location filename="../utils.cpp" line="30"/>
         <source>%1 ago</source>
         <translation>vor %1</translation>
     </message>
     <message>
-        <location filename="../utils.cpp" line="31"/>
+        <location filename="../utils.cpp" line="33"/>
         <source>right now</source>
         <translation>gerade eben</translation>
     </message>
     <message>
-        <location filename="../utils.cpp" line="42"/>
+        <location filename="../utils.cpp" line="44"/>
         <source>unknown</source>
         <translation>unbekannt</translation>
     </message>
     <message numerus="yes">
-        <location filename="../utils.cpp" line="58"/>
+        <location filename="../utils.cpp" line="60"/>
         <source>%1 file(s)</source>
         <translation>
             <numerusform>%1 Datei</numerusform>
@@ -343,7 +361,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../utils.cpp" line="59"/>
+        <location filename="../utils.cpp" line="61"/>
         <source>%1 dir(s)</source>
         <translation>
             <numerusform>%1 Verz.</numerusform>
@@ -351,44 +369,44 @@
         </translation>
     </message>
     <message>
-        <location filename="../utils.cpp" line="74"/>
+        <location filename="../utils.cpp" line="76"/>
         <source>Synchronization of local directory %1 complete</source>
         <translation>%1 wurde lokal synchronisiert</translation>
     </message>
     <message>
-        <location filename="../utils.cpp" line="82"/>
+        <location filename="../utils.cpp" line="84"/>
         <source>Synchronization of the following local directories complete:
 </source>
         <translation>Folgende Verzeichnisse wurden lokal synchronisiert:
 </translation>
     </message>
     <message>
-        <location filename="../utils.cpp" line="96"/>
+        <location filename="../utils.cpp" line="98"/>
         <source>file system watcher and periodic rescan disabled</source>
         <translation>Dateisystemüberwachung und periodischer Scan deaktiviert</translation>
     </message>
     <message>
-        <location filename="../utils.cpp" line="98"/>
+        <location filename="../utils.cpp" line="100"/>
         <source>file system watcher active, periodic rescan disabled</source>
         <translation>Dateisystemüberwachung aktiv, periodischer Scan deaktiviert</translation>
     </message>
     <message>
-        <location filename="../utils.cpp" line="101"/>
+        <location filename="../utils.cpp" line="103"/>
         <source>, file system watcher enabled</source>
         <translation>, Dateisystemüberwachung aktiviert</translation>
     </message>
     <message>
-        <location filename="../utils.cpp" line="102"/>
+        <location filename="../utils.cpp" line="104"/>
         <source>, file system watcher disabled</source>
         <translation>, Dateisystemüberwachung deaktiviert</translation>
     </message>
     <message>
-        <location filename="../utils.cpp" line="77"/>
+        <location filename="../utils.cpp" line="79"/>
         <source>Synchronization of %1 on %2 complete</source>
         <translation>%1 wurde auf %2 synchronisiert</translation>
     </message>
     <message>
-        <location filename="../utils.cpp" line="85"/>
+        <location filename="../utils.cpp" line="87"/>
         <source>Synchronization of the following directories on %1 complete:
 </source>
         <translation>Folgende Verzeichnisse wurden auf %1 synchronisiert:
@@ -444,12 +462,12 @@
 <context>
     <name>SyncthingDir</name>
     <message>
-        <location filename="../syncthingdir.cpp" line="152"/>
+        <location filename="../syncthingdir.cpp" line="171"/>
         <source>paused</source>
         <translation>pausiert</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="154"/>
+        <location filename="../syncthingdir.cpp" line="173"/>
         <source>unshared</source>
         <translation>nicht geteilt</translation>
     </message>
@@ -467,27 +485,42 @@
         <translation>untätig</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="21"/>
+        <location filename="../syncthingdir.cpp" line="23"/>
         <source>waiting to scan</source>
         <translation>wartet aufs Scannen</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="23"/>
+        <location filename="../syncthingdir.cpp" line="21"/>
         <source>scanning</source>
         <translation>scannt</translation>
     </message>
     <message>
         <location filename="../syncthingdir.cpp" line="25"/>
+        <source>waiting to sync</source>
+        <translation>wartet aufs Synchronisieren</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="27"/>
         <source>preparing to sync</source>
         <translation>bereitet Synchronisation vor</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="27"/>
+        <location filename="../syncthingdir.cpp" line="29"/>
         <source>synchronizing</source>
         <translation>synchronisiert</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="29"/>
+        <location filename="../syncthingdir.cpp" line="31"/>
+        <source>cleaning</source>
+        <translation>Versionen bereinigen</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="33"/>
+        <source>waiting to clean</source>
+        <translation>wartet auf Bereinigung</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="35"/>
         <source>out of sync</source>
         <translation>nicht synchronisiert</translation>
     </message>
@@ -495,22 +528,22 @@
 <context>
     <name>SyncthingDirType</name>
     <message>
-        <location filename="../syncthingdir.cpp" line="38"/>
+        <location filename="../syncthingdir.cpp" line="44"/>
         <source>unknown</source>
         <translation>unbekannt</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="40"/>
+        <location filename="../syncthingdir.cpp" line="46"/>
         <source>Send &amp; Receive</source>
         <translation>Senden &amp; Empfangen</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="42"/>
+        <location filename="../syncthingdir.cpp" line="48"/>
         <source>Send only</source>
         <translation>Nur senden</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="44"/>
+        <location filename="../syncthingdir.cpp" line="50"/>
         <source>Receive only</source>
         <translation>Nur empfangen</translation>
     </message>
