@@ -55,11 +55,13 @@ namespace Plasmoid {
 
 static inline QPalette paletteFromTheme(const Plasma::Theme &theme)
 {
-#if 0 && PLASMA_VERSION_MAJOR >= 5 && PLASMA_VERSION_MINOR >= 68
+#if PLASMA_VERSION_MAJOR >= 5 && PLASMA_VERSION_MINOR >= 68
     return theme.palette();
 #else
     auto p = QPalette();
     p.setColor(QPalette::Normal, QPalette::Text, theme.color(Plasma::Theme::TextColor));
+    p.setColor(QPalette::Normal, QPalette::WindowText, theme.color(Plasma::Theme::TextColor));
+    p.setColor(QPalette::Normal, QPalette::Window, theme.color(Plasma::Theme::BackgroundColor));
     return p;
 #endif
 }
@@ -85,6 +87,7 @@ SyncthingApplet::SyncthingApplet(QObject *parent, const QVariantList &data)
     , m_currentConnectionConfig(-1)
     , m_hasInternalErrors(false)
     , m_initialized(false)
+    , m_showTabTexts(false)
 {
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
     m_notifier.setService(&m_service);
@@ -149,7 +152,9 @@ void SyncthingApplet::init()
     m_currentConnectionConfig = config().readEntry<int>("selectedConfig", 0);
 
     // apply settings and connect according to settings
-    setBrightColors(isPaletteDark(paletteFromTheme(m_theme)));
+    const auto palette = paletteFromTheme(m_theme);
+    setBrightColors(isPaletteDark(palette));
+    IconManager::instance().setPalette(palette);
     handleSettingsChanged();
 
     m_initialized = true;
@@ -370,12 +375,8 @@ void SyncthingApplet::showOwnDeviceId()
 void SyncthingApplet::showAboutDialog()
 {
     if (!m_aboutDlg) {
-        m_aboutDlg = new AboutDialog(nullptr, QStringLiteral(APP_NAME),
-            QStringLiteral("<p>Developed by " APP_AUTHOR "<br>Syncthing icons from <a href=\"https://syncthing.net\">Syncthing project</a><br>Using "
-                           "icons from <a href=\"https://forkaweso.me\">Fork "
-                           "Awesome</a> (see <a href=\"https://forkaweso.me/Fork-Awesome/license\">their license</a>)</p>"),
-            QStringLiteral(APP_VERSION), CppUtilities::applicationInfo.dependencyVersions, QStringLiteral(APP_URL), QStringLiteral(APP_DESCRIPTION),
-            renderSvgImage(makeSyncthingIcon(), QSize(128, 128)).toImage());
+        m_aboutDlg = new AboutDialog(nullptr, QStringLiteral(APP_NAME), aboutDialogAttribution(), QStringLiteral(APP_VERSION),
+            CppUtilities::applicationInfo.dependencyVersions, QStringLiteral(APP_URL), QStringLiteral(APP_DESCRIPTION), aboutDialogImage());
         m_aboutDlg->setWindowTitle(tr("About") + QStringLiteral(" - " APP_NAME));
         m_aboutDlg->setWindowIcon(QIcon::fromTheme(QStringLiteral("syncthingtray")));
         m_aboutDlg->setAttribute(Qt::WA_DeleteOnClose);
@@ -451,6 +452,7 @@ void SyncthingApplet::handleSettingsChanged()
 
     // apply appearance settings
     setSize(config.readEntry<QSize>("size", QSize(25, 25)));
+    setShowingTabTexts(config.readEntry<bool>("showTabTexts", false));
     IconManager::instance().applySettings(&settings.icons.status);
 
     // restore selected states
