@@ -84,6 +84,7 @@ TrayWidget::TrayWidget(TrayMenu *parent)
     , m_recentChangesModel(m_connection)
     , m_selectedConnection(nullptr)
     , m_startStopButtonTarget(StartStopButtonTarget::None)
+    , m_tabTextsShown(true)
 {
     // don't show connection status within connection settings if there are multiple tray widgets/icons (would be ambiguous)
     if (!s_instances.empty() && s_settingsDlg) {
@@ -99,6 +100,11 @@ TrayWidget::TrayWidget(TrayMenu *parent)
     }
 
     m_ui->setupUi(this);
+    const auto tabCount = m_ui->tabWidget->count();
+    m_tabTexts.reserve(tabCount);
+    for (decltype(m_ui->tabWidget->count()) i = 0; i != tabCount; ++i) {
+        m_tabTexts << m_ui->tabWidget->tabText(i);
+    }
 
     // setup models and views
     m_ui->dirsTreeView->header()->setSortIndicator(0, Qt::AscendingOrder);
@@ -233,7 +239,7 @@ TrayWidget::~TrayWidget()
     }
 }
 
-void TrayWidget::showSettingsDialog()
+SettingsDialog *TrayWidget::settingsDialog()
 {
     if (!s_dialogParent) {
         s_dialogParent = new QWidget();
@@ -248,9 +254,14 @@ void TrayWidget::showSettingsDialog()
         //       by simply saving the settings immediately.
         connect(s_settingsDlg, &SettingsDialog::applied, &Settings::save);
     }
+    return s_settingsDlg;
+}
 
+void TrayWidget::showSettingsDialog()
+{
+    auto *const dlg = settingsDialog();
     // show settings dialog centered or maximized if the relatively big windows would overflow
-    showDialog(s_settingsDlg, centerWidgetAvoidingOverflow(s_settingsDlg));
+    showDialog(dlg, centerWidgetAvoidingOverflow(dlg));
 }
 
 void TrayWidget::showAboutDialog()
@@ -259,13 +270,8 @@ void TrayWidget::showAboutDialog()
         s_dialogParent = new QWidget();
     }
     if (!s_aboutDlg) {
-        s_aboutDlg = new AboutDialog(s_dialogParent, QString(),
-            QStringLiteral(
-                "<p>Developed by " APP_AUTHOR
-                "<br>Fallback icons from KDE/Breeze project<br>Syncthing icons from <a href=\"https://syncthing.net\">Syncthing project</a><br>Using "
-                "icons from <a href=\"https://forkaweso.me\">Fork "
-                "Awesome</a> (see <a href=\"https://forkaweso.me/Fork-Awesome/license\">their license</a>)</p>"),
-            QString(), {}, QStringLiteral(APP_URL), QString(), renderSvgImage(makeSyncthingIcon(), QSize(128, 128)).toImage());
+        s_aboutDlg = new AboutDialog(
+            s_dialogParent, QString(), aboutDialogAttribution(), QString(), {}, QStringLiteral(APP_URL), QString(), aboutDialogImage());
         s_aboutDlg->setWindowTitle(tr("About") + QStringLiteral(" - " APP_NAME));
         s_aboutDlg->setWindowIcon(QIcon(QStringLiteral(":/icons/hicolor/scalable/app/syncthingtray.svg")));
     }
@@ -505,6 +511,20 @@ void TrayWidget::applySettings(const QString &connectionConfig)
         m_ui->tabWidget->setTabPosition(static_cast<QTabWidget::TabPosition>(settings.appearance.tabPosition));
     }
     IconManager::instance().applySettings(&settings.icons.status, settings.icons.distinguishTrayIcons ? &settings.icons.tray : nullptr);
+    if (m_tabTextsShown != settings.appearance.showTabTexts) {
+        const auto tabCount = m_ui->tabWidget->count();
+        if ((m_tabTextsShown = settings.appearance.showTabTexts)) {
+            for (decltype(m_ui->tabWidget->count()) i = 0; i != tabCount; ++i) {
+                m_ui->tabWidget->setTabText(i, m_tabTexts[i]);
+                m_ui->tabWidget->setTabToolTip(i, QString());
+            }
+        } else {
+            for (decltype(m_ui->tabWidget->count()) i = 0; i != tabCount; ++i) {
+                m_ui->tabWidget->setTabText(i, QString());
+                m_ui->tabWidget->setTabToolTip(i, m_tabTexts[i]);
+            }
+        }
+    }
 
     // update status icon and text of tray icon because reconnect interval might have changed
     if (m_menu && m_menu->icon()) {
