@@ -16,6 +16,7 @@
 // use meta-data of syncthingtray application here
 #include "resources/../../tray/resources/config.h"
 
+#include <qtutilities/resources/resources.h>
 #include <qtutilities/settingsdialog/qtsettings.h>
 #ifdef QT_UTILITIES_SUPPORT_DBUS_NOTIFICATIONS
 #include <qtutilities/misc/dbusnotification.h>
@@ -256,13 +257,9 @@ Settings &values()
 
 void restore()
 {
-    QSettings settings(QSettings::IniFormat, QSettings::UserScope, QStringLiteral(PROJECT_NAME));
-    // move old config to new location
-    const QString oldConfig
-        = QSettings(QSettings::IniFormat, QSettings::UserScope, QApplication::organizationName(), QApplication::applicationName()).fileName();
-    QFile::rename(oldConfig, settings.fileName()) || QFile::remove(oldConfig);
-    settings.sync();
-    Settings &v = values();
+    auto s = QtUtilities::getSettings(QStringLiteral(PROJECT_NAME));
+    auto &v = values();
+    auto &settings = *s;
 
     const auto version = QVersionNumber::fromString(settings.value(QStringLiteral("v")).toString());
     settings.beginGroup(QStringLiteral("tray"));
@@ -338,6 +335,7 @@ void restore()
     v.ignoreInavailabilityAfterStart = settings.value(QStringLiteral("ignoreInavailabilityAfterStart"), v.ignoreInavailabilityAfterStart).toUInt();
     auto &appearance = v.appearance;
     appearance.showTraffic = settings.value(QStringLiteral("showTraffic"), appearance.showTraffic).toBool();
+    appearance.showTabTexts = settings.value(QStringLiteral("showTabTexts"), appearance.showTabTexts).toBool();
     appearance.trayMenuSize = settings.value(QStringLiteral("trayMenuSize"), appearance.trayMenuSize).toSize();
     appearance.frameStyle = settings.value(QStringLiteral("frameStyle"), appearance.frameStyle).toInt();
     appearance.tabPosition = settings.value(QStringLiteral("tabPos"), appearance.tabPosition).toInt();
@@ -402,9 +400,9 @@ void restore()
 
 void save()
 {
-    QSettings settings(QSettings::IniFormat, QSettings::UserScope, QStringLiteral(PROJECT_NAME));
-
-    const Settings &v = values();
+    auto s = QtUtilities::getSettings(QStringLiteral(PROJECT_NAME));
+    auto &settings = *s;
+    const auto &v = values();
 
     settings.setValue(QStringLiteral("v"), QStringLiteral(APP_VERSION));
     settings.beginGroup(QStringLiteral("tray"));
@@ -448,6 +446,7 @@ void save()
     settings.setValue(QStringLiteral("ignoreInavailabilityAfterStart"), v.ignoreInavailabilityAfterStart);
     const auto &appearance = v.appearance;
     settings.setValue(QStringLiteral("showTraffic"), appearance.showTraffic);
+    settings.setValue(QStringLiteral("showTabTexts"), appearance.showTabTexts);
     settings.setValue(QStringLiteral("trayMenuSize"), appearance.trayMenuSize);
     settings.setValue(QStringLiteral("frameStyle"), appearance.frameStyle);
     settings.setValue(QStringLiteral("tabPos"), appearance.tabPosition);
