@@ -59,7 +59,8 @@ struct SYNCTHINGWIDGETS_EXPORT NotifyOn {
 
 struct SYNCTHINGWIDGETS_EXPORT Appearance {
     bool showTraffic = true;
-    QSize trayMenuSize = QSize(450, 400);
+    bool showTabTexts = true;
+    QSize trayMenuSize = QSize(575, 475);
     int frameStyle = static_cast<int>(QFrame::NoFrame) | static_cast<int>(QFrame::Plain);
     int tabPosition = QTabWidget::South;
     struct SYNCTHINGWIDGETS_EXPORT Positioning {
@@ -150,6 +151,8 @@ struct SYNCTHINGWIDGETS_EXPORT WebView {
 
 struct SYNCTHINGWIDGETS_EXPORT Settings {
     bool firstLaunch = false;
+    bool fakeFirstLaunch = false; // not persistent, for testing purposes only
+    bool enableWipFeatures = false; // not persistent, for testing purposes only
     Connection connection;
     NotifyOn notifyOn;
 #ifdef QT_UTILITIES_SUPPORT_DBUS_NOTIFICATIONS
