@@ -1,4 +1,6 @@
 #include "./settingsdialog.h"
+#include "./settings.h"
+#include "./wizard.h"
 
 #include "../misc/syncthinglauncher.h"
 
@@ -29,6 +31,7 @@
 
 #include <qtutilities/misc/compat.h>
 #include <qtutilities/misc/desktoputils.h>
+#include <qtutilities/misc/dialogutils.h>
 #include <qtutilities/paletteeditor/colorbutton.h>
 #include <qtutilities/settingsdialog/optioncategory.h>
 #include <qtutilities/settingsdialog/optioncategorymodel.h>
@@ -462,6 +465,7 @@ bool AppearanceOptionPage::apply()
     settings.trayMenuSize.setWidth(ui()->widthSpinBox->value());
     settings.trayMenuSize.setHeight(ui()->heightSpinBox->value());
     settings.showTraffic = ui()->showTrafficCheckBox->isChecked();
+    settings.showTabTexts = ui()->showTabTextsCheckBox->isChecked();
     int style;
     switch (ui()->frameShapeComboBox->currentIndex()) {
     case 0:
@@ -500,6 +504,7 @@ void AppearanceOptionPage::reset()
     ui()->widthSpinBox->setValue(settings.trayMenuSize.width());
     ui()->heightSpinBox->setValue(settings.trayMenuSize.height());
     ui()->showTrafficCheckBox->setChecked(settings.showTraffic);
+    ui()->showTabTextsCheckBox->setChecked(settings.showTabTexts);
     int index;
     switch (settings.frameStyle & QFrame::Shape_Mask) {
     case QFrame::NoFrame:
@@ -1463,10 +1468,30 @@ void SettingsDialog::init()
     setWindowIcon(
         QIcon::fromTheme(QStringLiteral("preferences-other"), QIcon(QStringLiteral(":/icons/hicolor/scalable/apps/preferences-other.svg"))));
 
+    // add button for starting wizard
+    if (!::Settings::values().enableWipFeatures) {
+        return;
+    }
+    auto *startWizardButton = new QPushButton(this);
+    startWizardButton->setToolTip(tr("Start wizard"));
+    startWizardButton->setIcon(
+        QIcon::fromTheme(QStringLiteral("tools-wizard"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/tools-wizard.svg"))));
+    startWizardButton->setFlat(true);
+    startWizardButton->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
+    connect(startWizardButton, &QPushButton::clicked, this, &SettingsDialog::showWizard);
+    addHeadingWidget(startWizardButton);
+
     // some settings could be applied without restarting the application, good idea?
     //connect(this, &Dialogs::SettingsDialog::applied, bind(&Dialogs::QtSettings::apply, &Settings::qtSettings()));
 }
 
+void SettingsDialog::showWizard()
+{
+    auto *const wizard = Wizard::instance();
+    QtUtilities::centerWidget(wizard);
+    wizard->show();
+}
+
 void SettingsDialog::hideConnectionStatus()
 {
     m_connectionsOptionPage->hideConnectionStatus();
