@@ -86,6 +86,11 @@
         <source>Right</source>
         <translation>右边</translation>
     </message>
+    <message>
+        <location filename="../settings/appearanceoptionpage.ui" line="335"/>
+        <source>Show tab texts</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Colors</source>
         <translation type="vanished">颜色</translation>
@@ -100,40 +105,40 @@
         <translation>可选 GUI 元素</translation>
     </message>
     <message>
-        <location filename="../settings/appearanceoptionpage.ui" line="225"/>
+        <location filename="../settings/appearanceoptionpage.ui" line="328"/>
         <source>Traffic statistics</source>
         <translation>流量数据</translation>
     </message>
     <message>
-        <location filename="../settings/appearanceoptionpage.ui" line="232"/>
+        <location filename="../settings/appearanceoptionpage.ui" line="225"/>
         <source>Positioning</source>
         <translation>定位</translation>
     </message>
     <message>
-        <location filename="../settings/appearanceoptionpage.ui" line="244"/>
+        <location filename="../settings/appearanceoptionpage.ui" line="237"/>
         <source>Use cursor position</source>
         <translation>使用光标位置</translation>
     </message>
     <message>
-        <location filename="../settings/appearanceoptionpage.ui" line="254"/>
+        <location filename="../settings/appearanceoptionpage.ui" line="247"/>
         <source>Otherwise assume tray icon coordinates to be:</source>
         <translation>否则假设托盘图标坐标为：</translation>
     </message>
     <message>
         <location filename="../settings/appearanceoptionpage.ui" line="146"/>
         <location filename="../settings/appearanceoptionpage.ui" line="184"/>
-        <location filename="../settings/appearanceoptionpage.ui" line="272"/>
-        <location filename="../settings/appearanceoptionpage.ui" line="294"/>
+        <location filename="../settings/appearanceoptionpage.ui" line="265"/>
+        <location filename="../settings/appearanceoptionpage.ui" line="287"/>
         <source> px</source>
         <translation> 像素</translation>
     </message>
     <message>
-        <location filename="../settings/appearanceoptionpage.ui" line="275"/>
+        <location filename="../settings/appearanceoptionpage.ui" line="268"/>
         <source>x: </source>
         <translation>x: </translation>
     </message>
     <message>
-        <location filename="../settings/appearanceoptionpage.ui" line="297"/>
+        <location filename="../settings/appearanceoptionpage.ui" line="290"/>
         <source>y: </source>
         <translation>y: </translation>
     </message>
@@ -161,31 +166,69 @@
         <translation>桌面环境启动时启动托盘图标</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="723"/>
+        <location filename="../settings/settingsdialog.cpp" line="727"/>
         <source>This is achieved by adding a *.desktop file under &lt;i&gt;~/.config/autostart&lt;/i&gt; so the setting only affects the current user.</source>
         <translation>这是通过在 &lt;i&gt;~/.config/autostart&lt;/i&gt; 下添加 *.desktop 文件来实现的，因此该设置仅影响当前用户。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="726"/>
+        <location filename="../settings/settingsdialog.cpp" line="730"/>
         <source>This is achieved by adding a registry key under &lt;i&gt;HKEY_CURRENT_USER\SOFTWARE\Microsoft\Windows\CurrentVersion\Run&lt;/i&gt; so the setting only affects the current user. Note that the startup entry is invalidated when moving &lt;i&gt;syncthingtray.exe&lt;/i&gt;.</source>
         <translation>这是通过在 &lt;i&gt;HKEY_CURRENT_USER\SOFTWARE\Microsoft\Windows\CurrentVersion\Run&lt;/i&gt; 下添加注册表项来实现的，因此该设置仅影响当前用户。 请注意，移动 &lt;i&gt;syncthingtray.exe&lt;/i&gt; 时启动项无效。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="730"/>
+        <location filename="../settings/settingsdialog.cpp" line="734"/>
         <source>This is achieved by adding a *.plist file under &lt;i&gt;~/Library/LaunchAgents&lt;/i&gt; so the setting only affects the current user.</source>
         <translation>这是通过在 &lt;i&gt;~/Library/LaunchAgents&lt;/i&gt; 下添加 *.plist 文件来实现的，因此该设置仅影响当前用户。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="734"/>
+        <location filename="../settings/settingsdialog.cpp" line="738"/>
         <source>This feature has not been implemented for your platform (yet).</source>
         <translation>此功能尚未为您的平台实现。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="865"/>
+        <location filename="../settings/settingsdialog.cpp" line="869"/>
         <source>unable to modify startup entry</source>
         <translation>无法修改启动项</translation>
     </message>
 </context>
+<context>
+    <name>QtGui::AutostartWizardPage</name>
+    <message>
+        <location filename="../settings/autostartwizardpage.ui" line="6"/>
+        <source>General</source>
+        <translation type="unfinished">一般</translation>
+    </message>
+    <message>
+        <location filename="../settings/autostartwizardpage.ui" line="16"/>
+        <source>Start Syncthing-Tray on login (only affects sessions of the current user)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/autostartwizardpage.ui" line="43"/>
+        <source>You previously selected to start Syncthing via the built-in launcher so Syncthing itself will be started automatically on login as well.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/autostartwizardpage.ui" line="53"/>
+        <source>You previously selected to start Syncthing via systemd so its systemd-unit will be enabled. This means Syncthing itself will start automatically independently of this setting which only affects the tray icon.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/autostartwizardpage.ui" line="63"/>
+        <source>Since Syncthing is running independently of Syncthing Tray on your system, this does not affect when Syncthing itself is launched.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="532"/>
+        <source>Configure autostart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="533"/>
+        <source>Select whether to start Syncthing Tray automatically</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QtGui::ConnectionOptionPage</name>
     <message>
@@ -357,27 +400,27 @@
         <translation>应用连接设置并尝试使用当前选择的配置重新连接</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="101"/>
+        <location filename="../settings/settingsdialog.cpp" line="103"/>
         <source>Auto-detected for local instance</source>
         <translation>本地实例自动检测</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="134"/>
+        <location filename="../settings/settingsdialog.cpp" line="136"/>
         <source>Select Syncthing config file</source>
         <translation>选择 Syncthing 配置文件</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="142"/>
+        <location filename="../settings/settingsdialog.cpp" line="144"/>
         <source>Unable to parse the Syncthing config file.</source>
         <translation>无法解析 Syncthing 配置文件。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="233"/>
+        <location filename="../settings/settingsdialog.cpp" line="235"/>
         <source>Unable to load specified certificate &quot;%1&quot;.</source>
         <translation>无法加载指定的证书 &quot;%1&quot;。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="258"/>
+        <location filename="../settings/settingsdialog.cpp" line="260"/>
         <source>Instance %1</source>
         <translation>实例 %1</translation>
     </message>
@@ -441,6 +484,43 @@
         <translation>打开网页 UI</translation>
     </message>
 </context>
+<context>
+    <name>QtGui::DetectionWizardPage</name>
+    <message>
+        <location filename="../settings/wizard.cpp" line="281"/>
+        <source>Checking current Syncthing setup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="282"/>
+        <source>Checking Syncthing configuration and whether Syncthing is already running or can be started …</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="333"/>
+        <source>It looks like Syncthing has not been running on this system before as its configuration cannot be found. Is that correct?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="329"/>
+        <source>Yes, continue configuration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="330"/>
+        <source>No, let me select Syncthing&apos;s configuration file manually</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="339"/>
+        <source>Select Syncthing&apos;s configuration file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>no</source>
+        <translation type="obsolete">否</translation>
+    </message>
+</context>
 <context>
     <name>QtGui::DirectoryErrorsDialog</name>
     <message>
@@ -542,47 +622,47 @@
 <context>
     <name>QtGui::IconsOptionPageBase</name>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="558"/>
+        <location filename="../settings/settingsdialog.cpp" line="562"/>
         <source>UI icons</source>
         <translation>UI 图标</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="560"/>
+        <location filename="../settings/settingsdialog.cpp" line="564"/>
         <source>These icon settings are used within Syncthing Tray&apos;s UI.</source>
         <translation>这些图标设置在 Syncthing Tray 的 UI 中使用。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="564"/>
+        <location filename="../settings/settingsdialog.cpp" line="568"/>
         <source>System icons</source>
         <translation>系统图标</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="565"/>
+        <location filename="../settings/settingsdialog.cpp" line="569"/>
         <source>These icon settings are used for the system tray icon and the notifications.</source>
         <translation>这些图标设置用于系统托盘图标和通知。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="567"/>
+        <location filename="../settings/settingsdialog.cpp" line="571"/>
         <source>Use same settings as for UI icons</source>
         <translation>使用与 UI 图标相同的设置</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="623"/>
+        <location filename="../settings/settingsdialog.cpp" line="627"/>
         <source>Colorful background with gradient (default)</source>
         <translation>带渐变的彩色背景（默认）</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="628"/>
+        <location filename="../settings/settingsdialog.cpp" line="632"/>
         <source>Transparent background and dark foreground (for bright themes)</source>
         <translation>透明背景和深色前景（适用于明亮的主题）</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="633"/>
+        <location filename="../settings/settingsdialog.cpp" line="637"/>
         <source>Transparent background and bright foreground (for dark themes)</source>
         <translation>透明背景和明亮前景（用于深色主题）</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="649"/>
+        <location filename="../settings/settingsdialog.cpp" line="653"/>
         <source>%1 px (scaled to %2 px)</source>
         <translation>%1 像素（缩放到 %2 像素）</translation>
     </message>
@@ -710,7 +790,7 @@
     </message>
     <message>
         <location filename="../settings/launcheroptionpage.ui" line="197"/>
-        <location filename="../settings/settingsdialog.cpp" line="1040"/>
+        <location filename="../settings/settingsdialog.cpp" line="1044"/>
         <source>Stop launched instance</source>
         <translation>停止启动的实例</translation>
     </message>
@@ -725,86 +805,178 @@
         <translation>确保最新日志可见</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="912"/>
+        <location filename="../settings/settingsdialog.cpp" line="916"/>
         <source>%1-launcher</source>
         <translation>%1-启动器</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="913"/>
+        <location filename="../settings/settingsdialog.cpp" line="917"/>
         <source>Launch %1 when starting the tray icon</source>
         <translation>启动托盘图标时启动 %1</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="916"/>
+        <location filename="../settings/settingsdialog.cpp" line="920"/>
         <source>%1 executable</source>
         <translation>%1 可执行文件</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="917"/>
+        <location filename="../settings/settingsdialog.cpp" line="921"/>
         <source>%1 log (interleaved stdout/stderr)</source>
         <translation>%1 日志（交错的标准输出/标准错误）</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="933"/>
+        <location filename="../settings/settingsdialog.cpp" line="937"/>
         <source>Restore default</source>
         <translation>还原至默认</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="939"/>
+        <location filename="../settings/settingsdialog.cpp" line="943"/>
         <source>Show Syncthing releases/downloads</source>
         <translation>显示 Syncthing 发布/下载</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1075"/>
+        <location filename="../settings/settingsdialog.cpp" line="1079"/>
         <source>%1 exited with exit code %2</source>
         <translation>%1 退出，退出代码为 %2</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1078"/>
+        <location filename="../settings/settingsdialog.cpp" line="1082"/>
         <source>%1 crashed with exit code %2</source>
         <translation>%1 崩溃，退出代码为 %2</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1111"/>
+        <location filename="../settings/settingsdialog.cpp" line="1115"/>
         <source>failed to start (e.g. executable does not exist or not permission error)</source>
         <translation>启动失败（例如可执行文件不存在或没有权限）</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1114"/>
+        <location filename="../settings/settingsdialog.cpp" line="1118"/>
         <source>process crashed</source>
         <translation>进程崩溃</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1117"/>
+        <location filename="../settings/settingsdialog.cpp" line="1121"/>
         <source>timeout error</source>
         <translation>超时错误</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1120"/>
+        <location filename="../settings/settingsdialog.cpp" line="1124"/>
         <source>read error</source>
         <translation>读取错误</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1123"/>
+        <location filename="../settings/settingsdialog.cpp" line="1127"/>
         <source>write error</source>
         <translation>写入错误</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1126"/>
+        <location filename="../settings/settingsdialog.cpp" line="1130"/>
         <source>unknown process error</source>
         <translation>未知进程错误</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1129"/>
+        <location filename="../settings/settingsdialog.cpp" line="1133"/>
         <source>An error occurred when running %1: %2</source>
         <translation>运行 %1 时出错: %2</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1182"/>
+        <location filename="../settings/settingsdialog.cpp" line="1186"/>
         <source>Kill launched instance</source>
         <translation>强制终止启动的实例</translation>
     </message>
 </context>
+<context>
+    <name>QtGui::MainConfigWizardPage</name>
+    <message>
+        <location filename="../settings/wizard.cpp" line="360"/>
+        <source>Select what configuration to apply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="361"/>
+        <source>Something when wrong when checking the Syncthing setup.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="362"/>
+        <source>Show details from setup detection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="434"/>
+        <source>Systemd</source>
+        <translation type="unfinished">Systemd</translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="441"/>
+        <source>Syncthing Tray</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="456"/>
+        <source>Looks like Syncthing is not running yet. You can launch it via %1.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="456"/>
+        <source> and </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/mainconfigwizardpage.ui" line="6"/>
+        <source>General</source>
+        <translation type="unfinished">一般</translation>
+    </message>
+    <message>
+        <location filename="../settings/mainconfigwizardpage.ui" line="16"/>
+        <source>Configure Syncthing Tray for currently running Syncthing instance</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/mainconfigwizardpage.ui" line="23"/>
+        <source>Start installed Syncthing application via Syncthing Tray</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/mainconfigwizardpage.ui" line="30"/>
+        <source>Start Syncthing application that is built into Syncthing Tray</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/mainconfigwizardpage.ui" line="37"/>
+        <source>Start Syncthing via systemd user-unit (enables and starts the unit %1)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/mainconfigwizardpage.ui" line="44"/>
+        <source>Start Syncthing via systemd system-unit (enables and starts the unit %1)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/mainconfigwizardpage.ui" line="51"/>
+        <source>Enable systemd-integration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/mainconfigwizardpage.ui" line="78"/>
+        <source>Click next to configure Syncthing Tray according to the selected options. You can also reconduct the checks the available options are based on by heading back. If you cancel the wizard, no configuration changes will be made.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>no</source>
+        <translation type="obsolete">否</translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="410"/>
+        <source>Looks like Syncthing is already running and Syncthing Tray can be configured accordingly automatically.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="458"/>
+        <source>Looks like Syncthing is not running yet and needs to be installed before Syncthing Tray can be configured.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QtGui::NotificationsOptionPage</name>
     <message>
@@ -897,7 +1069,7 @@
         <translation> 秒</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="420"/>
+        <location filename="../settings/settingsdialog.cpp" line="422"/>
         <source>Configured to use D-Bus notifications but D-Bus notification daemon seems unavailabe.</source>
         <translation>配置为使用 DBus 通知，但 D-Bus 通知守护程序似乎不可用。</translation>
     </message>
@@ -923,35 +1095,40 @@
 <context>
     <name>QtGui::SettingsDialog</name>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1425"/>
+        <location filename="../settings/settingsdialog.cpp" line="1429"/>
         <source>Tray</source>
         <translation>托盘</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1432"/>
+        <location filename="../settings/settingsdialog.cpp" line="1436"/>
         <source>Web view</source>
         <translation>网页视图</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1439"/>
+        <location filename="../settings/settingsdialog.cpp" line="1443"/>
         <source>Startup</source>
         <translation>启动</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1441"/>
+        <location filename="../settings/settingsdialog.cpp" line="1445"/>
         <source>additional tool</source>
         <translation>附加工具</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1441"/>
+        <location filename="../settings/settingsdialog.cpp" line="1445"/>
         <source>Extra launcher</source>
         <translation>额外启动器</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1462"/>
+        <location filename="../settings/settingsdialog.cpp" line="1466"/>
         <source>Settings</source>
         <translation>设置</translation>
     </message>
+    <message>
+        <location filename="../settings/settingsdialog.cpp" line="1475"/>
+        <source>Start wizard</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QtGui::StatusInfo</name>
@@ -1125,8 +1302,8 @@ This dialog closes automatically when the process finally terminates.</source>
         <location filename="../settings/systemdoptionpage.ui" line="109"/>
         <location filename="../settings/systemdoptionpage.ui" line="164"/>
         <location filename="../settings/systemdoptionpage.ui" line="253"/>
-        <location filename="../settings/settingsdialog.cpp" line="1320"/>
-        <location filename="../settings/settingsdialog.cpp" line="1329"/>
+        <location filename="../settings/settingsdialog.cpp" line="1324"/>
+        <location filename="../settings/settingsdialog.cpp" line="1333"/>
         <source>unknown</source>
         <translation>未知</translation>
     </message>
@@ -1161,27 +1338,27 @@ This dialog closes automatically when the process finally terminates.</source>
         <translation>禁用</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1218"/>
+        <location filename="../settings/settingsdialog.cpp" line="1222"/>
         <source>Reload all unit files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1256"/>
+        <location filename="../settings/settingsdialog.cpp" line="1260"/>
         <source>It is not possible to show the start/stop button for the systemd service and the internal launcher at the same time. The systemd service precedes.</source>
         <translation>无法同时显示 systemd 服务和内部启动器的启动/停止按钮。 systemd 服务优先。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1262"/>
+        <location filename="../settings/settingsdialog.cpp" line="1266"/>
         <source>It is not possible to consider the systemd service and the internal launcher for reconnects at the same time. The systemd service precedes.</source>
         <translation>无法同时考虑 systemd 服务和内部启动器进行重新连接。 systemd 服务优先。</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1293"/>
+        <location filename="../settings/settingsdialog.cpp" line="1297"/>
         <source>specified unit is either inactive or doesn&apos;t exist</source>
         <translation>指定的单位不活动或不存在</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1315"/>
+        <location filename="../settings/settingsdialog.cpp" line="1319"/>
         <source>since </source>
         <translation>自从 </translation>
     </message>
@@ -1219,7 +1396,7 @@ This dialog closes automatically when the process finally terminates.</source>
     <name>QtGui::WebViewOptionPage</name>
     <message>
         <location filename="../settings/webviewoptionpage.ui" line="12"/>
-        <location filename="../settings/settingsdialog.cpp" line="1372"/>
+        <location filename="../settings/settingsdialog.cpp" line="1376"/>
         <source>General</source>
         <translation>一般</translation>
     </message>
@@ -1249,17 +1426,223 @@ This dialog closes automatically when the process finally terminates.</source>
         <translation>当前未显示时保持网页视图运行</translation>
     </message>
     <message>
-        <location filename="../settings/settingsdialog.cpp" line="1374"/>
+        <location filename="../settings/settingsdialog.cpp" line="1378"/>
         <source>Syncthing Tray has not been built with vieb view support utilizing either Qt WebKit or Qt WebEngine.
 The Web UI will be opened in the default web browser instead.</source>
         <translation>Syncthing Tray 尚未使用 Qt WebKit 或 Qt WebEngine 构建支持网页视图。
 网页 UI 将改为在默认网页浏览器中打开。</translation>
     </message>
 </context>
+<context>
+    <name>QtGui::WelcomeWizardPage</name>
+    <message>
+        <location filename="../settings/wizard.cpp" line="198"/>
+        <source>Welcome to Syncthing Tray</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="199"/>
+        <source>It looks like you&apos;re launching Syncthing Tray for the first time.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="200"/>
+        <source>You must configure how to connect to Syncthing and how to launch Syncthing (if that&apos;s wanted) when using Syncthing Tray the first time.  A guided/automated setup is still in the works so the manual setup is currently the only option.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="204"/>
+        <source>Wizard&apos;s start page</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="205"/>
+        <source>This wizard will help you configuring Syncthing Tray.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="211"/>
+        <source>Start guided setup</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="213"/>
+        <source>Allows to configure Syncthing Tray automatically for the local Syncthing instance and helps you starting Syncthing if wanted.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="221"/>
+        <source>Configure connection and launcher settings manually</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="223"/>
+        <source>Head back to settings to configure connection and launcher manually</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="226"/>
+        <source>Note that the connection settings allow importing URL, credentials and API-key from the local Syncthing configuration.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="242"/>
+        <source>Show Syncthing&apos;s documentation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="243"/>
+        <source>It contains general information about configuring Syncthing.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="249"/>
+        <source>Show Syncthing Tray&apos;s README</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="250"/>
+        <source>It contains documentation about this GUI integration specifically.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QtGui::Wizard</name>
+    <message>
+        <location filename="../settings/wizard.cpp" line="43"/>
+        <source>Setup wizard - </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="109"/>
+        <source>Unable to locate Syncthing config file.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="111"/>
+        <source>Located Syncthing config file: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="113"/>
+        <source>Syncthing config file looks ok.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="115"/>
+        <source>Syncthing config file looks invalid/incomplete.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="118"/>
+        <source>Syncthing configuration:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="126"/>
+        <source>Could connect to Syncthing under: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="127"/>
+        <source>Syncthing version: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="128"/>
+        <source>Syncthing device ID: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="129"/>
+        <source>Syncthing status: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="131"/>
+        <source>Additional Syncthing status info: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="134"/>
+        <source>Coult NOT connect to Syncthing under: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="136"/>
+        <source>API connection:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="139"/>
+        <source>API connection errors:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="146"/>
+        <source>State of user unit file &quot;%1&quot;: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="147"/>
+        <source>State of system unit file &quot;%1&quot;: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="144"/>
+        <source>Systemd:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="150"/>
+        <source>No available</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="156"/>
+        <source>Could test-launch Syncthing successfully, exit code: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="157"/>
+        <source>Syncthing version returned from test-launch: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="159"/>
+        <source>Unable to test-launch Syncthing: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="161"/>
+        <source>Built-in Syncthing available: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="161"/>
+        <source>yes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="161"/>
+        <source>no</source>
+        <translation type="unfinished">否</translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="162"/>
+        <source>Launcher:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/wizard.cpp" line="168"/>
+        <source>Details from setup detection - </source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Settings::restore</name>
     <message>
-        <location filename="../settings/settings.cpp" line="316"/>
+        <location filename="../settings/settings.cpp" line="313"/>
         <source>Unable to load certificate &quot;%1&quot; when restoring settings.</source>
         <translation>还原设置时无法加载证书 &quot;%1&quot;。</translation>
     </message>
